@@ -29,11 +29,11 @@
 #include "gwcontact.h"
 #include <qmap.h>
 
-#include <kaction.h>
+#include <QAction>
 #include <KActionCollection>
 #include <kdebug.h>
-#include <kicon.h>
-#include <klocale.h>
+#include <QIcon>
+#include <KLocalizedString>
 
 #include <kopetemetacontact.h>
 #include <kopeteuiglobal.h>
@@ -75,7 +75,7 @@ QString GroupWiseContact::dn() const
 
 void GroupWiseContact::updateDetails( const ContactDetails & details )
 {
-	kDebug() ;
+	qDebug() ;
 	if ( !details.cn.isNull() )
 		setProperty( protocol()->propCN, QVariant(details.cn) );
 	if ( !details.dn.isNull() )
@@ -93,16 +93,16 @@ void GroupWiseContact::updateDetails( const ContactDetails & details )
 	m_serverProperties = details.properties;
 	
 	// work phone number
-	if ( m_serverProperties.contains( "telephoneNumber" ) )
-		setProperty( protocol()->propPhoneWork, QVariant(m_serverProperties.value( "telephoneNumber" )) );
+	if ( m_serverProperties.contains( QStringLiteral("telephoneNumber") ) )
+		setProperty( protocol()->propPhoneWork, QVariant(m_serverProperties.value( QStringLiteral("telephoneNumber") )) );
 	
 	// mobile phone number
-	if ( m_serverProperties.contains( "mobile" ) )
-		setProperty( protocol()->propPhoneMobile, QVariant(m_serverProperties.value( "mobile" )) );
+	if ( m_serverProperties.contains( QStringLiteral("mobile") ) )
+		setProperty( protocol()->propPhoneMobile, QVariant(m_serverProperties.value( QStringLiteral("mobile") )) );
 	
 	// email
-	if ( m_serverProperties.contains( "Internet EMail Address" ) )
-		setProperty( protocol()->propEmail, QVariant(m_serverProperties.value( "Internet EMail Address" )) );
+	if ( m_serverProperties.contains( QStringLiteral("Internet EMail Address") ) )
+		setProperty( protocol()->propEmail, QVariant(m_serverProperties.value( QStringLiteral("Internet EMail Address") )) );
 		
 	if ( details.status != GroupWise::Invalid )
 	{	
@@ -139,28 +139,28 @@ bool GroupWiseContact::isReachable()
 
 void GroupWiseContact::serialize( QMap< QString, QString > &serializedData, QMap< QString, QString > & /* addressBookData */ )
 {
-	serializedData[ "DN" ] = m_dn;
+	serializedData[ QStringLiteral("DN") ] = m_dn;
 }
 
 Kopete::ChatSession * GroupWiseContact::manager( Kopete::Contact::CanCreateFlags canCreate )
 {
-	//kDebug() << "called, canCreate: " << canCreate;
+	//qDebug() << "called, canCreate: " << canCreate;
 
 	Kopete::ContactPtrList chatMembers;
 	chatMembers.append( this );
 
-	return account()->chatSession( chatMembers, QString("")/*FIXME Check this is right*/, canCreate );
+    return account()->chatSession( chatMembers, QString("")/*FIXME Check this is right*/, canCreate );
 }
 
-QList<KAction*> *GroupWiseContact::customContextMenuActions()
+QList<QAction *> *GroupWiseContact::customContextMenuActions()
 {
-	QList<KAction *> * actions = new QList<KAction *>;
+	QList<QAction *> * actions = new QList<QAction *>;
 
 	// Block/unblock contact
 	QString label = account()->isContactBlocked( m_dn ) ? i18n( "Unblock User" ) : i18n( "Block User" );
 	if( !m_actionBlock )
 	{
-		m_actionBlock = new KAction( KIcon( "msn_blocked" ), label, 0 );
+		m_actionBlock = new QAction( QIcon::fromTheme(QStringLiteral("msn_blocked")), label, 0 );
 		QObject::connect( m_actionBlock, SIGNAL(triggered(bool)), SLOT(slotBlock()) );
 	}
 	else
@@ -178,7 +178,7 @@ QList<KAction*> *GroupWiseContact::customContextMenuActions()
 void GroupWiseContact::slotUserInfo()
 {
 	GroupWiseContactProperties *p = new GroupWiseContactProperties( this, Kopete::UI::Global::mainWidget() );
-	p->setObjectName( "gwcontactproperties" );
+	p->setObjectName( QStringLiteral("gwcontactproperties") );
 }
 
 QMap< QString, QVariant > GroupWiseContact::serverProperties()
@@ -188,7 +188,7 @@ QMap< QString, QVariant > GroupWiseContact::serverProperties()
 
 void GroupWiseContact::sendMessage( Kopete::Message &message )
 {
-	kDebug() ;
+	qDebug() ;
 	manager()->appendMessage( message );
 	// tell the manager it was sent successfully
 	manager()->messageSucceeded();
@@ -206,7 +206,7 @@ void GroupWiseContact::sync( unsigned int)
 
 void GroupWiseContact::slotBlock()
 {
-	kDebug() ;
+	qDebug() ;
 	if ( account()->isConnected() )
 	{
 		if ( account()->isContactBlocked( m_dn ) )
@@ -234,7 +234,7 @@ void GroupWiseContact::setOnlineStatus( const Kopete::OnlineStatus& status )
 	if ( account()->isContactBlocked( m_dn ) && status.internalStatus() < 15 )
 	{
 		Kopete::Contact::setOnlineStatus(Kopete::OnlineStatus(status.status(), (status.weight()==0) ? 0 : (status.weight() -1),
-			protocol() , status.internalStatus()+15 , QStringList("msn_blocked"),
+			protocol() , status.internalStatus()+15 , QStringList(QStringLiteral("msn_blocked")),
 			i18n("%1|Blocked", status.description() ) ) );
 	}
 	else
@@ -294,7 +294,7 @@ void GroupWiseContact::renamedOnServer()
 		setNickName( uct->displayName() );
 	}
 	else
-		kDebug() << "rename failed, return code: " << uct->statusCode();
+		qDebug() << "rename failed, return code: " << uct->statusCode();
 }
 
 void GroupWiseContact::setMessageReceivedOffline( bool on )
@@ -307,7 +307,3 @@ bool GroupWiseContact::messageReceivedOffline() const
 	return m_messageReceivedOffline;
 }
 
-#include "gwcontact.moc"
-
-// vim: set noet ts=4 sts=4 sw=4:
-
